# Pacifica Data Cart
![PyPi](https://img.shields.io/pypi/v/pacifica-cartd.svg)
![Read the Docs](https://readthedocs.org/projects/pacifica-cartd/badge/?version=latest)
[![Build Status](https://travis-ci.org/pacifica/pacifica-cartd.svg?branch=master)](https://travis-ci.org/pacifica/pacifica-cartd)
[![Build status](https://ci.appveyor.com/api/projects/status/d6fd3fugytxeh5qp?svg=true)](https://ci.appveyor.com/project/dmlb2000/pacifica-cartd)
[![Code Climate](https://codeclimate.com/github/pacifica/pacifica-cartd/badges/gpa.svg)](https://codeclimate.com/github/pacifica/pacifica-cartd)
[![Issue Count](https://codeclimate.com/github/pacifica/pacifica-cartd/badges/issue_count.svg)](https://codeclimate.com/github/pacifica/pacifica-cartd)
## Docker Containers
[![Docker Stars](https://img.shields.io/docker/stars/pacifica/cartd-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/cartd-frontend/general)
[![Docker Pulls](https://img.shields.io/docker/pulls/pacifica/cartd-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/cartd-frontend/general)
[![Docker Automated build](https://img.shields.io/docker/automated/pacifica/cartd-frontend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/cartd-frontend/builds)
[![Docker Stars](https://img.shields.io/docker/stars/pacifica/cartd-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/cartd-backend/general)
[![Docker Pulls](https://img.shields.io/docker/pulls/pacifica/cartd-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/cartd-backend/general)
[![Docker Automated build](https://img.shields.io/docker/automated/pacifica/cartd-backend.svg?maxAge=2592000)](https://cloud.docker.com/swarm/pacifica/repository/docker/pacifica/cartd-backend/builds)


Pacifica data cart for bundling and transfer of data sets.

This manages the bundling of data from the [archive interface]
(https://github.com/pacifica/pacifica-archiveinterface) and presents
APIs for users to use.

## Documentation

For installation, configuration and usage documentation please
refer to the [Read the Docs](https://pacifica-cartd.readthedocs.io)
documentation.

* [Installation](docs/installation.md) documentation.
* [Configuration](docs/configuration.md) documentation.
* [Examples](docs/exampleusage.md) documentation.
